@@ -37,3 +37,7 @@ class JSONFormatter(Formatter):
         formatted_json = dumps(json_data, cls=self.customjson, sort_keys=True,
                                separators=(',', ': '), indent=4)
         return formatted_json
+
+if __name__ == "__main__":
+    # execute only if run as a script
+    main()
\ No newline at end of file
